@@ -314,9 +314,10 @@
           if(i==1){
             rm.obs<-c(rm.obs, trans[-c(1:(length(trans)/sum(super.trait==k)))])
           }
+          size<-as.numeric(substr(object$family[trans[1:(length(trans)/2)]], 11, nchar(object$family[trans[1:(length(trans)/2)]])))
           prob<-matrix(ynew[trans,i], length(trans)/sum(super.trait==k), sum(super.trait==k))
           prob[,2]<-rbinom(nrow(prob), 1, 1-plogis(prob[,2]))
-          prob[,2][which(prob[,2]==1)]<-rbinom(sum(prob[,2]==1), 1, plogis(prob[,1][which(prob[,2]==1)]))
+          prob[,2][which(prob[,2]==1)]<-rbinom(sum(prob[,2]==1), size, plogis(prob[,1][which(prob[,2]==1)]))
           ynew[trans,i]<-prob[,2]
         }
       }
